module.exports = defineTest({
	description: 'deconflicts top-level classes'
});
